library(tidyverse)
library(rstan)

source('./coef_labels.R')

# Neuromodulation variance
stanNmod <- readRDS("./../../output/stan_models/stan_neuromod.rds")
NmodCoefs <- extract(stanNmod, pars = c("alpha","gamma0","beta","gamma"))

coefdf <- as.data.frame(cbind(NmodCoefs$gamma0, NmodCoefs$gamma))
colnames(coefdf) <- c("gamma0", Nmod_labs)
coefdf <- coefdf %>% gather("Var","Val")

group_stats <- coefdf %>%
group_by(Var) %>%
summarise(med = median(Val),
firstq = quantile(Val, 0.025),
secondq = quantile(Val, 0.975))
group_stats

coefdf %>%
  ggplot() +
  geom_density(aes(Val, fill = 1)) +
  geom_vline(data = group_stats,
             aes(xintercept = med), color = "red") +
  geom_vline(data = group_stats,
             aes(xintercept = firstq), color = "grey") +
  geom_vline(data = group_stats,
             aes(xintercept = secondq), color = "grey") +
  facet_grid(Var ~ ., switch = "y") +
  theme_minimal() +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.text.y = element_blank(),
        legend.position = "none",
        strip.text.y = element_text(angle = 180, hjust = 1)) +
  geom_vline(aes(xintercept = 0)) +
  ggtitle('neuromodulation variance effects') +
  xlab("odor preference variance effect size") +
  ylab("")

# Thermogenetics variance
stanShibire <- readRDS("./../../output/stan_models/stan_shibire.rds")
ShibireCoefs <- extract(stanShibire, pars = c("alpha","gamma0","beta","gamma"))

stanTrp <- readRDS("./../../output/stan_models/stan_TrpA.rds")
TrpACoefs <- extract(stanTrp, pars = c("alpha","gamma0","beta","gamma"))

TrpCoefdf <- as.data.frame(cbind(TrpACoefs$gamma0, TrpACoefs$gamma))
ShiCoefdf <- as.data.frame(cbind(ShibireCoefs$gamma0, ShibireCoefs$gamma))

colnames(TrpCoefdf) <- c("gamma0", TrpA_labs)
colnames(ShiCoefdf) <- c("gamma0", shibire_labs)

TrpCoefdf <- TrpCoefdf %>% gather("Var","Val")
ShiCoefdf <- ShiCoefdf %>% gather("Var","Val")
coefdf <- rbind(TrpCoefdf, ShiCoefdf)

group_stats <- coefdf %>% filter(str_detect(Var, "29C") | str_detect(Var, "32C")) %>%
group_by(Var) %>%
summarise(med = median(Val),
firstq = quantile(Val, 0.025),
secondq = quantile(Val, 0.975))
group_stats

coefdf %>% filter(str_detect(Var, "29C") | str_detect(Var, "32C")) %>%
  ggplot() +
    geom_density(aes(Val, fill = str_detect(Var, "29C"))) +
    geom_vline(data = group_stats,
               aes(xintercept = med), color = "red") +
    geom_vline(data = group_stats,
               aes(xintercept = firstq), color = "grey") +
    geom_vline(data = group_stats,
               aes(xintercept = secondq), color = "grey") +
    facet_grid(Var ~ ., switch = "y") +
    theme_minimal() +
    theme(panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank(),
          axis.text.y = element_blank(),
          legend.position = "none",
          strip.text.y = element_text(angle = 180, hjust = 1)) +
    geom_vline(aes(xintercept = 0)) +
    ggtitle('GAL4 variance effects') +
    xlab("odor preference variance effect size") +
    ylab("")
