function f = plotKDEwCI(data, saveName, plotTitle, ylims)
% data is a cell array, containing one occupancy vector per group

if nargin < 4
    ylims = 'auto';
end

if nargin < 3
    plotTitle = '';
end

if nargin < 2
    doSave = 0;
else
    doSave = 1;
end

% Set x-vals to calculate KDE for
x = linspace(0,1,200);

% Bootstrap params
N_IT = 1e4;
N_PT = length(x);

% Display params
cols = {'k','b','r'};

f = figure; hold on;

for j = 1:length(data)
    
    obs_vec = data{j};
    
    % Find censored points
    obs_cens = ((obs_vec == 0) | (obs_vec ==1));
    
    % Get empirical KDE
    obs_kd = ksdensity(obs_vec, x, 'Censoring', obs_cens);
    
    
    % Bootstrap the KDE CI
    obs_err = zeros(N_IT, N_PT);
    
    parfor i = 1:N_IT
        bs_samp = datasample(obs_vec, length(obs_vec));
        bs_cens = ((bs_samp == 0) | (bs_samp ==1));
        obs_err(i,:) = ksdensity(bs_samp, x, 'Censoring', bs_cens) - obs_kd;
    end
    
    obs_err_upper = obs_kd - prctile(obs_err, 2.5, 1);
    obs_err_lower = obs_kd - prctile(obs_err, 97.5, 1);
    
    % Take care of negative densities
    obs_err_upper(obs_err_upper < 0) = 0;
    obs_err_lower(obs_err_lower < 0) = 0;
    
    
    patch([x, fliplr(x)], [obs_err_lower, fliplr(obs_err_upper)], cols{j}, 'FaceAlpha', 0.2, 'EdgeColor', 'none')
    hold on;
    plot(x, obs_kd, 'Color', cols{j});
    
end

ylim(ylims);
title(plotTitle);

ax = gca;
ax.PlotBoxAspectRatio = [3 2 1];
f.PaperUnits = 'inches';
f.PaperPosition = [0 0 6 4];

if doSave
    savefig([saveName, '_kde.fig'])
    print('-fillpage',[saveName, '_kde'],'-dpdf');
end
